#!/usr/bin/python3
import time
import config_python
from twitchAPI.twitch import Twitch
import logging
from logging.handlers import TimedRotatingFileHandler
from termcolor import colored
import os
import sys
streamer = config_python.streamer
app_id = config_python.appid
app_secret = config_python.appsecret

log_format = logging.Formatter('%(asctime)s %(levelname)s:%(message)s')
log_file = 'output.log'


# Если стрим идет
def stream_message_worker(data: dict):
    # Если это стрим, а не повтор, значит все в порядке
    if data['type'] == 'live':
        game_name = data['game_name']
        stream_title = data['title']
        stream_viewers = str(data['viewer_count'])
        log.info(streamer + " стримит " + game_name + " Title: " + stream_title + " Зрителей: " + stream_viewers)


# Если стрим не идет
def no_stream_msg_worker():
    log.info(streamer + " Не стримит")


def check_alive():
    """
    1. Проверка на наличие стрима
    1.1 Если нет - удалить lock файл, если он есть
    1.2 Если есть - создать lock файл, запустить записывалку
    """

    # Получаем инфо о стримере, если не получается, выходим с ошибкой
    resolved_id = twitch_client.get_users(logins=[streamer])
    if not resolved_id['data']:
        log.error(
            colored(
                "Аккаунт " + streamer + " не найден",
                'red',
            )
        )
    # Достаем ID стримера из инфо
    user_id = resolved_id['data'][0]['id']
    # Получаем стримы
    user_stream = twitch_client.get_streams(user_id=user_id)
    # Если стрим/повтор идет, то идем дальше
    if user_stream['data']:
        stream_message_worker(user_stream['data'][0])
    else:
        # Если стрим не идет, то запускаем функцию без параметров
        no_stream_msg_worker()


def get_console_handler():
    console_handler = logging.StreamHandler(sys.stdout)
    console_handler.setFormatter(log_format)
    return console_handler


def get_file_handler():
    file_handler = TimedRotatingFileHandler(log_file, when='midnight')
    file_handler.setFormatter(log_format)
    return file_handler


def get_logger(logger_name):
    logger = logging.getLogger(logger_name)
    logger.setLevel(logging.DEBUG)
    logger.addHandler(get_console_handler())
    logger.addHandler(get_file_handler())
    logger.propagate = False
    return logger


if __name__ == '__main__':
    log = get_logger("main")
    log.info("Запущен")
    twitch_client = Twitch(app_id, app_secret)
    while True:
        check_alive()
        time.sleep(3)
